# Support

## Getting Help

If you need help with this project, here are your options:

### Documentation

Check the [README](README.md) for basic usage and setup instructions.

### Issues

Search [existing issues](../../issues) to see if your question has already been answered.

### Ask a Question

If you can't find an answer, open a new issue with:
- A clear description of your problem
- What you've already tried
- Relevant code snippets or error messages
- Your environment (OS, version, etc.)

### Response Time

This is an open-source project maintained by volunteers. Response times may vary, but we'll do our best to help when we can.

## Reporting Bugs

See [CONTRIBUTING.md](CONTRIBUTING.md) for guidelines on reporting bugs.

## Commercial Support

Commercial support is not currently available for this project.

---

Thank you for using this project!

